@@ -73,12 +73,12 @@
 #' \code{'stations_to_choose_from'} rows and 9 columns. This data frame contains information
 #' about the weather stations (Latitude, Longitude, among others). If
 #' \code{action = 'download_weather'}, the function returns a list of length according to the
-#' length of the \code{location} parameter. Each list, is a list of two elements; a data frame
-#' containing the data downloaded from the database and character string representing the
-#' respective database ('dwd'). If the \code{action} is provided with the list generated by
-#' the function in the downloading mode, the function will return a list of data frames structured
-#' according to the chillR format. If \code{drop_most} is set to \code{TRUE}, the function will
-#' keep only the relevant variables.
+#' length of the \code{location} parameter. Each list elements is a data frame
+#' containing the data downloaded from the database. If the \code{action} is provided
+#' with the list generated by the function in the downloading mode, the function will
+#' return a list of data frames structured according to the chillR format.
+#' If \code{drop_most} is set to \code{TRUE}, the function will keep only the
+#' most relevant variables for standard chillR analyses.
 #'  
 #' @note
 #' Many databases have data quality flags, which may sometimes indicate that data aren't reliable.
@@ -134,23 +134,14 @@ handle_dwd <- function(action,
   assertthat::assert_that(is.character(action) | is.list(action),
               msg = paste("'action' should be either a character string",
                           "('list_actions' or 'download_weather') or a list",
-                          "of two elements ('weather' and 'database').",
+                          "of weather data.frames.",
                           "Please provide a valid input."))
   
   if (is.character(action))
     assertthat::assert_that(action %in% c("list_stations", "download_weather"),
               msg = paste("Valid inputs for 'action' are 'list_stations'",
                           "or 'download_weather'. Please select one of these."))
-  
-  if (is.list(action))
-    assertthat::assert_that(
-      all(unlist(lapply(
-        action, function(x) 
-          names(x) %in% c("weather", "database")))),
-      msg = paste("The list provided in the 'action' argument does not comply",
-                  "with the required format. The list should contain the",
-                  "elements 'weather' and 'database'."))
-  
+
   # Location
   
   if (!is.null(names(location)))
@@ -257,7 +248,7 @@ handle_dwd <- function(action,
       paste0("https://opendata.dwd.de/climate_environment/CDC/",
              "observations_germany/climate/daily/kl/historical/",
              "KL_Tageswerte_Beschreibung_Stationen.txt"),
-      skip = 2, header = F, colClasses = "character")[, 1]
+      skip = 2, header = F, colClasses = "character", fileEncoding="latin1")[, 1]
     
     # Delete the extra white spaces at the end of the characters
     
@@ -280,7 +271,7 @@ handle_dwd <- function(action,
     
     # Encode the german umlauts
     
-    stations <- stringr::str_conv(stations, "ISO-8859-1")
+    # stations <- stringr::str_conv(stations, "ISO-8859-1")
     
     # Make a dataframe of the information about the stations in Germany
     
@@ -406,7 +397,7 @@ handle_dwd <- function(action,
         paste0("https://opendata.dwd.de/climate_environment/CDC/",
                "observations_germany/climate/daily/kl/historical/",
                "KL_Tageswerte_Beschreibung_Stationen.txt"),
-        skip = 2, header = F, colClasses = "character")[, 1]
+        skip = 2, header = F, colClasses = "character", fileEncoding="latin1")[, 1]
       
       # Delete the extra white spaces at the end of the characters
       stations <- trimws(stations)
@@ -424,7 +415,7 @@ handle_dwd <- function(action,
       stations <- stations[-wrong_rows]
       
       # Encode the german umlauts
-      stations <- stringr::str_conv(stations, "ISO-8859-1")
+      # stations <- stringr::str_conv(stations, "ISO-8859-1")
       
       # Make a dataframe of the information about the stations in Germany
       stations <- data.frame(
@@ -643,8 +634,7 @@ handle_dwd <- function(action,
       data["Station_ID"] <- stations_to_download[i]
       
       # Collect the outputs for a number of stations
-      download_weather_list[[i]] <- list(weather = data,
-                                         database = "dwd")
+      download_weather_list[[i]] <- data
       
       # Define the name of the element i in the collection list
       names(download_weather_list)[i] <-
@@ -666,8 +656,7 @@ handle_dwd <- function(action,
   
   # Main block to handle weather data already downloaded
   
-  if (is.list(action) & all(unlist(lapply(action,
-                                          function(x) x[["database"]] == "dwd")))){
+  if (is.list(action)){
     
     # Define the vars depending on the different inputs
     
@@ -699,21 +688,21 @@ handle_dwd <- function(action,
     for (i in 1 : length(action)){
       
       # add the missing columns
-      if (!("DATE" %in% colnames(action[[i]][["weather"]])) & add.DATE){
+      if (!("DATE" %in% colnames(action[[i]])) & add.DATE){
         
-        action[[i]][["weather"]] <- 
-          make_all_day_table(action[[i]][["weather"]], 
+        action[[i]] <- 
+          make_all_day_table(action[[i]], 
                              add.DATE = TRUE, no_variable_check = TRUE)
         
       }
       
-      if (!("Station_name" %in% colnames(action[[i]][["weather"]])) & add_station_name){
+      if (!("Station_name" %in% colnames(action[[i]])) & add_station_name){
         
-        action[[i]][["weather"]]["Station_name"] <- names(action)[i]
+        action[[i]]["Station_name"] <- names(action)[i]
       }
       
       # Select the columns 
-      modified_dataframes[[i]] <- action[[i]][["weather"]][, c(station_vars,
+      modified_dataframes[[i]] <- action[[i]][, c(station_vars,
                                                                time_vars, weather_vars)]
       
     }
